@@ -10,7 +10,7 @@ use Carp;
 require DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = "2.40";
+$VERSION = "2.43";
 
 $have_File_Spec = $INC{'File/Spec.pm'} || do 'File/Spec.pm';
 
@@ -442,12 +442,12 @@ sub parse {
   my $result = 0;
   
   if (defined $arg) {
+    local *@;
     if (ref($arg) and UNIVERSAL::isa($arg, 'IO::Handle')) {
       $ioref = $arg;
-    } elsif (tied($arg)) {
-      my $class = ref($arg);
-      no strict 'refs';
-      $ioref = $arg if defined &{"${class}::TIEHANDLE"};
+    } elsif ($] < 5.008 and defined tied($arg)) {
+      require IO::Handle;
+      $ioref = $arg;
     }
     else {
       require IO::Handle;
@@ -455,20 +455,28 @@ sub parse {
         no strict 'refs';
         $ioref = *{$arg}{IO} if defined *{$arg};
       };
-      undef $@;
+      if (ref($ioref) eq 'FileHandle') {
+        #for perl 5.10.x and possibly earlier, see t/file_open_scalar.t
+        require FileHandle;
+      }
     }
   }
   
   if (defined($ioref)) {
     my $delim = $self->{Stream_Delimiter};
     my $prev_rs;
+    my $ioclass = ref $ioref;
+    $ioclass = "IO::Handle" if !length $ioclass;
     
-    $prev_rs = ref($ioref)->input_record_separator("\n$delim\n")
+    $prev_rs = $ioclass->input_record_separator("\n$delim\n")
       if defined($delim);
-    
-    $result = ParseStream($parser, $ioref, $delim);
-    
-    ref($ioref)->input_record_separator($prev_rs)
+
+    eval { $result = ParseStream($parser, $ioref, $delim) };
+    if($@) {
+      $self->xpcroak("$@");
+    }
+
+    $ioclass->input_record_separator($prev_rs)
       if defined($delim);
   } else {
     $result = ParseString($parser, $arg);
@@ -921,7 +929,7 @@ including any internal or external DTD declarations.
 
 =item * XMLDecl           (Parser, Version, Encoding, Standalone)
 
-This handler is called for XML declarations. Version is a string containg
+This handler is called for XML declarations. Version is a string containing
 the version. Encoding is either undefined or contains an encoding string.
 Standalone is either undefined, or true or false. Undefined indicates
 that no standalone parameter was given in the XML declaration. True or
@@ -953,7 +961,7 @@ a prefix.
 =item new_ns_prefixes
 
 When called from a start tag handler, returns namespace prefixes declared
-with this start tag. If called elsewere (or if there were no namespace
+with this start tag. If called elsewhere (or if there were no namespace
 prefixes declared), it returns an empty list. Setting of the default
 namespace is indicated with '#default' as a prefix.
 
@@ -973,7 +981,7 @@ currently bound, '#default' appears in the list.
 
 Returns the string from the document that was recognized in order to call
 the current handler. For instance, when called from a start handler, it
-will give us the the start-tag string. The string is encoded in UTF-8.
+will give us the start-tag string. The string is encoded in UTF-8.
 This method doesn't return a meaningful string inside declaration handlers.
 
 =item original_string
@@ -1215,7 +1223,7 @@ name discovered in the @Encoding_Path path list is used.
 The encoding in the file is loaded and kept in the %Encoding_Table
 table. Earlier encodings of the same name are replaced.
 
-This function is automaticly called by expat when it encounters an encoding
+This function is automatically called by expat when it encounters an encoding
 it doesn't know about. Expat shouldn't call this twice for the same
 encoding name. The only reason users should use this function is to
 explicitly load an encoding not contained in the @Encoding_Path list.
